# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from ..category_resource_response import CategoryResourceResponse

__all__ = ["ResourceListResponse"]

ResourceListResponse = List[CategoryResourceResponse]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List

from .category_resource_response import CategoryResourceResponse

__all__ = ["CategoryDeleteResponse"]

CategoryDeleteResponse = Dict[str, List[CategoryResourceResponse]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .cost_data import CostData
from .requests_data import RequestsData

__all__ = ["TotalCostData", "BudgetTransactions"]


class BudgetTransactions(BaseModel):
    blocked: int

    blocked_external: int

    exceeded: int

    successful: int

    error: Optional[int] = None

    total: Optional[int] = None


class TotalCostData(BaseModel):
    cost: CostData

    requests: RequestsData

    budget_transactions: Optional[BudgetTransactions] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["BudgetTags"]


class BudgetTags(BaseModel):
    created_on: Optional[datetime] = None

    tag_id: Optional[int] = None

    tag_name: Optional[str] = None
